#!/usr/bin/env ruby

############################################################################
# Copyright 2009,2010 Benjamin Kellermann                                  #
#           2015 Sebastian Marske                                          #
#                                                                          #
# This file is part of Dudle.                                              #
#                                                                          #
# Dudle is free software: you can redistribute it and/or modify it under   #
# the terms of the GNU Affero General Public License as published by       #
# the Free Software Foundation, either version 3 of the License, or        #
# (at your option) any later version.                                      #
#                                                                          #
# Dudle is distributed in the hope that it will be useful, but WITHOUT ANY #
# WARRANTY; without even the implied warranty of MERCHANTABILITY or        #
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public     #
# License for more details.                                                #
#                                                                          #
# You should have received a copy of the GNU Affero General Public License #
# along with dudle.  If not, see <http://www.gnu.org/licenses/>.           #
############################################################################

if __FILE__ == $0


require_relative "dudle"

$d = Dudle.new

if $cgi.include?("create_poll") && ($conf.enable_custom_url ? $cgi.include?("poll_url") : true)
	POLLTITLE=$cgi["create_poll"]
	POLLDESC=$cgi["desc_poll"]
	if POLLTITLE == ""
		createnotice = _("Please enter a descriptive title.")
	else
		if $conf.enable_custom_url
			if $cgi["poll_url"] == ""
				guessurl = POLLTITLE.gsub(" ","_").gsub(/[\?\!\.]/,"")
				if guessurl =~ /^[a-zA-Z0-9_-]+$/ && !File.exist?(guessurl)
					POLLURL = guessurl
				else
					chars = ("a".."z").to_a + ("1".."9").to_a
					POLLURL = Array.new($conf.randpath_length){chars[rand(chars.size)]}.join
				end
			else
				POLLURL=$cgi["poll_url"]
			end
		else
			chars = ("a".."z").to_a + ("1".."9").to_a
			POLLURL = Array.new(20){chars[rand(chars.size)]}.join
		end


		if !(POLLURL =~ /\A[\w\-_]*\Z/)
			createnotice = _("Custom address may only contain letters, numbers, and dashes.")
		elsif File.exist?(POLLURL)
			createnotice = _("A poll with this address already exists.")
		else Dir.mkdir(POLLURL)
			Dir.chdir(POLLURL)
			begin
				VCS.init
				File.symlink("../participate.rb","index.cgi")
				["atom","customize", "history", "overview", "edit_columns","access_control", "delete_poll", "invite_participants"].each{|f|
					File.symlink("../#{f}.rb","#{f}.cgi")
				}
				["data.yaml",".htaccess",".htdigest"].each{|f|
					File.open(f,"w").close
					VCS.add(f)
				}
				Poll.new(CGI.escapeHTML(POLLTITLE),$cgi["poll_type"],CGI.escapeHTML(POLLDESC),$cgi["no_sort"])
				Dir.chdir("..")
				$d.html.header["status"] = "REDIRECT"
				$d.html.header["Cache-Control"] = "no-cache"
				$d.html.header["Location"] = $conf.siteurl + POLLURL + "/edit_columns.cgi"
				$d << _("The poll was created successfully. The link to your new poll is: %{link}") % {:link => "<br /><a href=\"#{POLLURL}\">#{POLLURL}</a>"}
			rescue WrongPollTypeError # should only happen in case of hacking
				Dir.chdir("..")
				require "fileutils"
				FileUtils.rm_r(POLLURL)
				$d.html.header["status"] = "REDIRECT"
				$d.html.header["Cache-Control"] = "no-cache"
				$d.html.header["Location"] = "http://localhost/"
				$d << _("Go away.")
			end
		end
	end
end

unless $d.html.header["status"] == "REDIRECT"

	$d << "<h2>"+ _("Create new poll") + "</h2>"

	titlestr = _("Title")
	descstr = _("Description")
	opthintstr = _("optional")
	typestr = _("Type")
	timepollstr = _("Event-scheduling poll (e.&thinsp;g., schedule a meeting)")
	normalpollstr = _("Normal poll (e.&thinsp;g., vote for what is the best coffee)")
	customaddrstr = _("Custom address (optional)")
	customaddrhintstr = _("May contain letters, numbers, and dashes.")
	nosortstr = _("Do not perform an automatic ordering of the columns by their name.")
	nosortnotice = _("This option does not affect event schedules.")

	createstr = _("Create")
	$d << <<CREATE
<form method='post' action='.'>
<table  class='settingstable'>
CREATE
	if defined?(createnotice)
		$d << <<NOTICE
<tr>
	<td colspan='2' class='error'>
		#{createnotice}
	</td>
</tr>
NOTICE
	end
	$d << <<CREATE
<tr>
	<td class='label'><label for="poll_name">#{titlestr}:</label></td>
	<td><input id="poll_name" size='40' type='text' name='create_poll' value="#{CGI.escapeHTML($cgi["create_poll"])}" /></td>
</tr>
<tr>
	<td class='label'><label for="poll_desc">#{descstr}:</label></td>
	<td><input id="poll_desc" size='40' type='text' name='desc_poll' value="#{CGI.escapeHTML($cgi["desc_poll"])}" /> (#{opthintstr})</td>
</tr>
<tr>
	<td class='label'>#{typestr}:</td>
	<td>
		<input id='chooseTime' type='radio' value='time' name='poll_type' checked='checked' />
		<label for='chooseTime'>#{timepollstr}</label>
		<br />
		<input id='chooseNormal' type='radio' value='normal' name='poll_type' />
		<label for='chooseNormal'>#{normalpollstr}</label>
	</td>
</tr>
<tr>
	<td class='label'></td>
	<td>
		<input id='preserveOrder' type='checkbox' value='1' name='no_sort' />
		<label for='preserveOrder'>#{nosortstr} (#{nosortnotice})</label>
	</td>
</tr>
<tr>
	<td></td>
	<td class='separator_bottom'><input type='submit' value='#{createstr}' /></td>
</tr>
CREATE
	if $conf.enable_custom_url
		$d << <<CREATE
<tr>
	<td colspan='2' class='separator_top'>#{customaddrstr}:
	<span class='hint'>#{customaddrhintstr}</span></td>
</tr>
<tr>
	<td colspan='2'><label for="poll_url">#{$conf.siteurl}</label><input id="poll_url" size='16' type='text' name='poll_url' value="#{CGI.escapeHTML($cgi["poll_url"])}" />
	</td>
</tr>
CREATE
	end
	$d << <<CREATE
</table>
</form>
CREATE

	$d << $conf.indexnotice
end

$d.out
end

